@@ -1,10 +1,10 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2023, by Samuel Williams.
+# Copyright, 2018-2025, by Samuel Williams.
 
-require 'async/http/endpoint'
-require 'localhost/authority'
+require "async/http/endpoint"
+require "localhost/authority"
 
 module Falcon
 	# An HTTP-specific endpoint which adds localhost TLS.
