@@ -1,10 +1,11 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2020-2024, by Samuel Williams.
+# Copyright, 2020-2025, by Samuel Williams.
 
-require_relative 'server'
-require_relative '../middleware/redirect'
+require_relative "server"
+require_relative "application"
+require_relative "../middleware/redirect"
 
 module Falcon
 	module Environment
